@echo off
cls

:: Initial Setup of SP2010-WFE1
:: by Dan Holme
::
:: The script is provided AS-IS
:: with no warranty expressed or implied
:: Use only in a test environment, at your own risk
::
:: (c) 2010 Intelliem, Inc.
::
:: This script may be used only as directed by the
:: Lab Environment Build Guide
:: that accompanies the 70-667 Training Kit
:: published by Microsoft Press.
:: The script may be used only in conjunction with 
:: study of the Training Kit
::
:: Contact dan.holme@intelliem.com for more information
::

SET DebugLog=YES
SET AllowChoice=NO
SET CourseID=70667TK
SET MachineRole=SP2010-WFE1

SET LocalFolder=C:\%CourseID%

SET Domain_NetBIOS=CONTOSO
SET Domain_DNS=contoso.com

SET Connection_Name=Local Area Connection
SET IP_Address=10.0.0.21
SET IP_Subnet=255.255.255.0
SET IP_Gateway=10.0.0.1
SET IP_DNS=10.0.0.11

SET RolesFeatures_Primary=RSAT-ADDS, RSAT-DNS-Server
SET RolesFeatures_Secondary=FS-FileServer, SMTP-Server, GPMC, Desktop-Experience

SET Domain_DNS=contoso.com
SET Domain_Admin_Username=CONTOSO\Administrator
SET Domain_Admin_Password=Pa$$w0rd

echo Initialize %MachineRole%
echo =============================================================================
echo.
echo Requirements:
echo Script must be executed by the local Administrator 
echo or with the Run As Administrator option
echo.

:: CHOICE /T 10 /D Y /M "Are all requirements met? Do you want to continue"
:: IF ERRORLEVEL 2 GOTO :EOF
:: echo.

IF x%CourseID%x==xx SET /p CourseID=Course ID: 
SET VMNAME=%CourseID%-%MachineRole%
IF %DebugLog%==YES SET LOGFILE=C:\%VMNAME%-SetupLog.txt
IF NOT %DebugLog%==YES SET LOGFILE=nul:
echo ======================================== >> %LOGFILE%
echo SCRIPT: %0 >> %LOGFILE%
echo DATE:   %DATE% %TIME% >> %LOGFILE%
echo USER:   %USERNAME% >> %LOGFILE%
echo ======================================== >> %LOGFILE%

:: INITIALIZE LOG
icacls %LOGFILE% /grant Users:F 1> nul:
IF %ERRORLEVEL%==0 echo Grant Users Full Control to %LOGFILE% & echo Grant Users Full Control to %LOGFILE%  >> %LOGFILE%

:: COPY MEDIA TO LOCAL FOLDER
SET LogStep=Grant Users Full Control to %LocalFolder%
md "%LocalFolder%"
icacls "%LocalFolder%" /grant Users:F 1> nul:
IF %ERRORLEVEL%==0 echo %LogStep% & echo %LogStep%  >> %LOGFILE%

SET LogStep=Copy VMSetup to %LocalFolder%
xcopy "D:\VMSetup" "%LocalFolder%\VMSetup" /i /e /y /q 1> nul:
IF %ERRORLEVEL%==0 echo %LogStep% & echo %LogStep%  >> %LOGFILE%

SET LogStep=Copy Practice Files to %LocalFolder%
xcopy "D:\Practice Files" "%LocalFolder%\Practice Files" /i /e /y /q 1> nul:
IF %ERRORLEVEL%==0 echo %LogStep% & echo %LogStep%  >> %LOGFILE%

SET LogStep=Set IPv4 address to %IP_Address% %IP_Subnet% %IP_Gateway%
netsh interface ipv4 set address name="%Connection_Name%" source=static address=%IP_Address% mask=%IP_Subnet% gateway=%IP_Gateway% gwmetric=1 1> nul:
IF %ERRORLEVEL%==0 echo %LogStep% & echo %LogStep%  >> %LOGFILE%

SET LogStep=Set primary DNS server to %IP_DNS% 
netsh dnsclient set dnsservers name="%Connection_Name%" source=static address=%IP_DNS% register=primary validate=no 1> nul:
IF %ERRORLEVEL%==0 echo %LogStep% & echo %LogStep%  >> %LOGFILE%

echo.
echo Installing %RolesFeatures_Primary%... Please wait...
SET LogStep=Installed roles and features - %RolesFeatures_Primary% 
powershell.exe Import-Module ServerManager; Add-WindowsFeature %RolesFeatures_Primary% 1> nul:
IF %ERRORLEVEL%==0 echo %LogStep% & echo %LogStep%  >> %LOGFILE%

:: echo.
:: echo Installing %RolesFeatures_Secondary%... Please wait...
:: SET LogStep=Installed roles and features - %RolesFeatures_Secondary%
:: powershell.exe Import-Module ServerManager; Add-WindowsFeature %RolesFeatures_Secondary%
:: IF %ERRORLEVEL%==0 echo %LogStep% & echo %LogStep%  >> %LOGFILE%

SET LogStep=Join domain %Domain_DNS%
netdom join %COMPUTERNAME% /Domain:%Domain_DNS% /UserD:%Domain_Admin_Username% /PasswordD:%Domain_Admin_Password% 1> nul:
IF %ERRORLEVEL%==0 echo %LogStep% & echo %LogStep%  >> %LOGFILE%

ping localhost > nul:
SET LogStep=Rename computer to %MachineRole%
netdom renamecomputer %computername% /newname:%MachineRole% /FORCE 1> nul:
IF %ERRORLEVEL%==0 echo %LogStep% & echo %LogStep%  >> %LOGFILE%

SET LogStep=Disable computer password resets
reg add HKLM\SYSTEM\CurrentControlSet\Services\Netlogon\Parameters /v "DisablePasswordChange" /t REG_DWORD /d 1 /f 1> nul:
IF %ERRORLEVEL%==0 echo %LogStep% & echo %LogStep%  >> %LOGFILE%

echo.
echo Script will restart the computer to complete the process

:Review
echo =============================================================================
echo COMPLETE
:: Reset ERRORLEVEL to 0
verify >nul
IF %AllowChoice%==YES CHOICE /T 10 /D N /M "Pause to review"
IF ERRORLEVEL 2 GOTO End
IF %AllowChoice%==NO GOTO End
pause

:End
echo.
pause
echo Restarting computer...
echo Restart computer >> %LOGFILE%
shutdown /t 0 /r

GOTO :EOF